@@ -231,7 +231,11 @@ def _parseUserEditAtom(blob):
     # encryptSessionPersistIdRef (4 bytes): An optional PersistIdRef
     # that specifies the value to look up in the persist object directory
     # to find the offset of the CryptSession10Container record (section 2.3.7).
-    encryptSessionPersistIdRef, = unpack("<I", blob.read(4))
+    buf = blob.read(4)
+    if len(buf) == 4:
+        encryptSessionPersistIdRef, = unpack("<I", buf)
+    else:
+        encryptSessionPersistIdRef = None
 
     return UserEditAtom(
         rh=rh,
